pub struct BatchedCounter { /* private fields */ }Expand description
Batches increments to a Prometheus [Counter] to reduce atomic contention.
Accumulates increments locally and flushes to the underlying counter when the batch threshold is reached or on drop.
Implementations